/**
 * Copyright (c) 2010 Alois Glomann gnalff@lucubrators.net
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.lucubrators.honeycomb.example;

import java.io.IOException;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import net.lucubrators.honeycomb.core.controller.FormObjectProvider;
import net.lucubrators.honeycomb.core.controller.HandleEvent;
import net.lucubrators.honeycomb.core.controller.Populate;
import net.lucubrators.honeycomb.core.messages.InfoMessage;
import net.lucubrators.honeycomb.core.messages.Message;
import net.lucubrators.honeycomb.core.messages.MessageLevel;
import net.lucubrators.honeycomb.core.messages.Messages;
import net.lucubrators.honeycomb.core.messages.SuccessMessage;
import net.lucubrators.honeycomb.core.shared.Model;
import net.lucubrators.honeycomb.core.shared.annotations.Param;
import net.lucubrators.honeycomb.core.view.View;
import net.lucubrators.honeycomb.defaultimpl.view.JSPView;

public class PojoController {

	private static final String	SESSION_KEY_POJO	= "pojo";

	@FormObjectProvider(name = "pojo", binder = "pojoBinder")
	public Pojo getPojo(HttpServletRequest request) {
		HttpSession session = request.getSession();
		Pojo aPojo = (Pojo) session.getAttribute(SESSION_KEY_POJO);
		if (aPojo == null) {
			aPojo = new Pojo();
			session.setAttribute(SESSION_KEY_POJO, aPojo);
		}
		return aPojo;
	}

	@Populate
	public View populate(Messages messages, @Param(name = "success", fallBack = "false") boolean success, Model model) {
		// The pojo is implicitly put into the model
		Pojo pojo = (Pojo) model.get("pojo");

		if (success) {
			messages.addMessage(new SuccessMessage("Your credentials have been successfully updated!!"));
			messages.addMessage(new SuccessMessage("Your new username: " + pojo.getUsername()));
			messages.addMessage(new SuccessMessage("Your new password: ***" + pojo.getPassword().substring(3)));
		} else {
			messages.addMessage(new InfoMessage("Please enter your credentials below"));
		}
		return new JSPView("/WEB-INF/jsp/pojo.jsp");
	}

	@HandleEvent
	public View handleEvent(HttpServletRequest request, HttpServletResponse response, Messages messages) throws IOException {
		List<Message> messagesByLevel = messages.getMessagesByLevel(MessageLevel.ERROR);
		if (messagesByLevel.isEmpty()) {
			response.sendRedirect(request.getContextPath() + "/ex3.html?success=true");
			return null;
		}
		return new JSPView("/WEB-INF/jsp/pojo.jsp");
	}
}
